pub struct PolicyLinter {}Expand description
Policy linting engine.
Performs static analysis of policy sets to detect misconfigurations, shadowed rules, and security anti-patterns.
Implementations
Sourceimpl PolicyLinter
impl PolicyLinter
Sourcepub fn lint(&self, policies: &[Policy]) -> LintReport
pub fn lint(&self, policies: &[Policy]) -> LintReport
Lint a set of policies and return a report.
Sourcepub fn lint_single(&self, policy: &Policy) -> Vec<LintFinding>
pub fn lint_single(&self, policy: &Policy) -> Vec<LintFinding>
Lint a single policy (subset of rules that apply to one policy).